@@ -587,10 +587,10 @@ class ER:
                     #print(["test", n1, n1["nodeType"]])
                     
                 if thisNodeType == str(NodeType.RELATION):
-                    if debugging: print(f"   checking relation for comparison")
+                    #if debugging: print(f"   checking relation for comparison")
                     
                     n2 = otherGraph.get_rel_adv(n1)
-                    if debugging: print(f"   found {n2['label']}")
+                    #if debugging: print(f"   found {n2['label']}")
                     if n2 == False:
                         if debugging: print(f" cannot get relation {n1['label']} for comparison ")
                         dist += scores['missing_object']
